@@ -1,4 +1,3 @@
-/* $Id: xfburn-blank-dialog.c 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -111,7 +110,7 @@ static XfceTitledDialogClass *parent_class = NULL;
 
 
 GType
-xfburn_blank_dialog_get_type ()
+xfburn_blank_dialog_get_type (void)
 {
   static GType type = 0;
 
@@ -532,7 +531,7 @@ cb_volume_changed (GtkWidget *device_box, gboolean device_changed, XfburnDevice
 
 /* public */
 GtkWidget *
-xfburn_blank_dialog_new ()
+xfburn_blank_dialog_new (void)
 {
   GtkWidget *obj;
 
