@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-audio-cd-composition-dialog.c 6350 2008-12-21 02:25:44Z squisher $ */
 /*
  *  Copyright (c) 2005-2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -76,17 +75,17 @@ static void xfburn_burn_audio_cd_composition_dialog_finalize (GObject * object);
 static void xfburn_burn_audio_cd_composition_dialog_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec);
 static void xfburn_burn_audio_cd_composition_dialog_set_property (GObject * object, guint prop_id, const GValue * value, GParamSpec * pspec);
 
-static void cb_disc_refreshed (GtkWidget *device_box, XfburnDevice *device, XfburnBurnAudioCdCompositionDialog * dialog);
+static void cb_volume_changed (GtkWidget *device_box, gboolean device_changed, XfburnDevice *device, XfburnBurnAudioCdCompositionDialog * dialog);
 static void cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_id,
                                 XfburnBurnAudioCdCompositionDialogPrivate * priv);
 
 /* globals */
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_burn_audio_cd_composition_dialog_get_type ()
+GType
+xfburn_burn_audio_cd_composition_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -154,8 +153,7 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
 
   /* burning devices list */
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_SPEED_SELECTION | ACCEPT_ONLY_CD);
-  g_signal_connect (G_OBJECT (priv->device_box), "disc-refreshed", G_CALLBACK (cb_disc_refreshed), obj);
-  g_signal_connect (G_OBJECT (priv->device_box), "device-changed", G_CALLBACK (cb_disc_refreshed), obj);
+  g_signal_connect (G_OBJECT (priv->device_box), "volume-changed", G_CALLBACK (cb_volume_changed), obj);
   gtk_widget_show (priv->device_box);
 
   priv->frame_device = xfce_create_framebox_with_content (_("Burning device"), priv->device_box);
@@ -229,7 +227,7 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
   gtk_widget_grab_focus (button);
   gtk_widget_grab_default (button);
 
-  cb_disc_refreshed (priv->device_box, xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
+  cb_volume_changed (priv->device_box, TRUE, xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
   g_signal_connect (G_OBJECT (obj), "response", G_CALLBACK (cb_dialog_response), priv);
 
   return gobj;
@@ -275,7 +273,7 @@ xfburn_burn_audio_cd_composition_dialog_finalize (GObject * object)
 
 /* internals */
 static void
-cb_disc_refreshed (GtkWidget *device_box, XfburnDevice *device, XfburnBurnAudioCdCompositionDialog * dialog)
+cb_volume_changed (GtkWidget *device_box, gboolean device_changed, XfburnDevice *device, XfburnBurnAudioCdCompositionDialog * dialog)
 {
   XfburnBurnAudioCdCompositionDialogPrivate *priv = XFBURN_BURN_AUDIO_CD_COMPOSITION_DIALOG_GET_PRIVATE (dialog);
   gboolean valid_disc;
@@ -322,36 +320,19 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   burn_options = burn_write_opts_new (drive);
   burn_write_opts_set_perform_opc (burn_options, 0);
   burn_write_opts_set_multi (burn_options, 0);
-
-  /* keep all modes here, just in case we want to change the default sometimes */
-  switch (params->write_mode) {
-  case WRITE_MODE_TAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_TAO, BURN_BLOCK_MODE1);
-    break;
-  case WRITE_MODE_SAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_SAO, BURN_BLOCK_SAO);
-    break;
-  case WRITE_MODE_RAW16:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW16);
-    break;
-  case WRITE_MODE_RAW96P:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96P);
-    break;
-  case WRITE_MODE_RAW96R:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96R);
-    break;
-  default:
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
-    return;
-  }
-
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
-  DBG ("Set speed to %d kb/s", params->speed);
-  burn_drive_set_speed (drive, 0, params->speed);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
-  burn_drive_set_buffer_waiting (drive, 1, -1, -1, -1, 75, 95);
 
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, AUDIO_BYTES_PER_SECTOR, disc, srcs, track_sectors);
+  if (!xfburn_set_write_mode (burn_options, params->write_mode, disc, WRITE_MODE_SAO)) {
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
+  } else {
+
+    DBG ("Set speed to %d kb/s", params->speed);
+    burn_drive_set_speed (drive, 0, params->speed);
+    burn_drive_set_buffer_waiting (drive, 1, -1, -1, -1, 75, 95);
+
+    xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, AUDIO_BYTES_PER_SECTOR, disc, srcs, track_sectors);
+  }
 
   burn_write_opts_free (burn_options);
 }
@@ -369,7 +350,7 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
   int i,j;
   GSList *track_list;
   int *track_sectors;
-  gboolean abort = FALSE;
+  gboolean abort_burn = FALSE;
   XfburnTranscoder *trans;
   GError *error = NULL;
 
@@ -392,7 +373,7 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
     if (tracks[i] == NULL) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), error->message);
       g_error_free (error);
-      abort = TRUE;
+      abort_burn = TRUE;
       break;
     }
     srcs[i] = atrack->src;
@@ -402,15 +383,15 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
     track_list = g_slist_next (track_list);
   }
 
-  if (!abort) {
+  if (!abort_burn) {
     if (!xfburn_transcoder_prepare (trans, &error)) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), error->message);
       g_error_free (error);
-      abort = TRUE;
+      abort_burn = TRUE;
     }
   }
 
-  if (!abort) {
+  if (!abort_burn) {
     if (!xfburn_device_grab (params->device, &drive_info)) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
     } else {
@@ -428,8 +409,6 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
   g_free (tracks);
   g_free (track_sectors);
 
-  for (track_list = params->tracks; track_list; track_list = g_slist_next (track_list))
-    xfburn_transcoder_free_burning_resources (trans, (XfburnAudioTrack *) track_list->data, NULL);
   g_object_unref (trans);
 
   burn_session_free (session);
@@ -445,6 +424,12 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
   if (response_id == GTK_RESPONSE_OK) {
     GtkWidget *dialog_progress;
 
+    ThreadBurnCompositionParams *params = NULL;
+    XfburnDevice *device;
+    gint speed;
+    XfburnWriteMode write_mode;
+    //struct burn_source * src_fifo = NULL;
+
     /* If the name was the default, update the image volume id and volset id */
     /*
     if (priv->entry != NULL) {
@@ -460,16 +445,10 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
     
     gtk_widget_show (dialog_progress);
 
-    ThreadBurnCompositionParams *params = NULL;
-    XfburnDevice *device;
-    gint speed;
-    XfburnWriteMode write_mode;
-    //struct burn_source * src_fifo = NULL;
-
     device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
     speed = xfburn_device_box_get_speed (XFBURN_DEVICE_BOX (priv->device_box));
-    /* cdrskin burns audio with SAO */
-    write_mode = WRITE_MODE_SAO;
+    /* cdrskin burns audio with SAO, but we assume auto knows that */
+    write_mode = WRITE_MODE_AUTO;
 
     /* burn composition */
     params = g_new0 (ThreadBurnCompositionParams, 1);
