@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-data-composition-base-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
 /*
  *  Copyright (c) 2005-2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -67,11 +66,14 @@ typedef struct
   */
 
   gint response;
+
+  gboolean show_volume_name;
 } XfburnBurnDataCompositionBaseDialogPrivate;
 
 enum {
   PROP_0,
-  PROP_IMAGE
+  PROP_IMAGE,
+  PROP_SHOW_VOLUME_NAME,
 };
 
 /*
@@ -103,17 +105,17 @@ static void cb_proceed_clicked (GtkButton * button, XfburnBurnDataCompositionBas
 */
 static void cb_check_only_iso_toggled (GtkToggleButton * button, XfburnBurnDataCompositionBaseDialog * dialog);
 static void cb_browse_iso (GtkButton * button, XfburnBurnDataCompositionBaseDialog * dialog);
-static void cb_disc_refreshed (GtkWidget *device_box, XfburnDevice *device, XfburnBurnDataCompositionBaseDialog * dialog);
+static void cb_volume_changed (XfburnDeviceBox *box, gboolean device_changed, XfburnDevice *device, XfburnBurnDataCompositionBaseDialog * dialog);
 static void cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_id,
                                 XfburnBurnDataCompositionBaseDialogPrivate * priv);
 
 /* globals */
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_burn_data_composition_base_dialog_get_type ()
+GType
+xfburn_burn_data_composition_base_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -126,6 +128,7 @@ xfburn_burn_data_composition_base_dialog_get_type ()
       sizeof (XfburnBurnDataCompositionBaseDialog),
       0,
       NULL,
+      NULL
     };
 
     type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBurnDataCompositionBaseDialog", &our_info, 0);
@@ -149,7 +152,9 @@ xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBa
 
   /* properties */
   g_object_class_install_property (object_class, PROP_IMAGE,
-				   g_param_spec_pointer ("image", "Image", "Image", G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+				   g_param_spec_pointer ("image", _("Image"), _("Image"), G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+  g_object_class_install_property (object_class, PROP_SHOW_VOLUME_NAME,
+				   g_param_spec_boolean ("show-volume-name", _("Show volume name"), _("Show a text entry for the name of the volume"), FALSE, G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 }
 
 static GObject *
@@ -183,17 +188,17 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
 
   /* burning devices list */
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_MODE_SELECTION | SHOW_SPEED_SELECTION);
-  g_signal_connect (G_OBJECT (priv->device_box), "disc-refreshed", G_CALLBACK (cb_disc_refreshed), obj);
-  g_signal_connect (G_OBJECT (priv->device_box), "device-changed", G_CALLBACK (cb_disc_refreshed), obj);
   gtk_widget_show (priv->device_box);
 
+  g_signal_connect (G_OBJECT (priv->device_box), "volume-changed", G_CALLBACK (cb_volume_changed), obj);
+
   priv->frame_device = xfce_create_framebox_with_content (_("Burning device"), priv->device_box);
   gtk_widget_show (priv->frame_device);
   gtk_box_pack_start (box, priv->frame_device, FALSE, FALSE, BORDER);
 
   /* composition name */
   comp_name = iso_image_get_volume_id (priv->image);
-  if (strcmp (comp_name, _(DATA_COMPOSITION_DEFAULT_NAME)) == 0) {
+  if (priv->show_volume_name) {
     GtkWidget *label;
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
@@ -275,7 +280,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->button_proceed = button = xfce_create_mixed_button ("xfburn-burn-cd", _("Burn Composition"));
+  priv->button_proceed = button = xfce_create_mixed_button ("xfburn-burn-cd", _("_Burn Composition"));
   /*
    * Disabled: change button_proceed functionality
   button = create_proceed_button (obj, "xfburn-burn-cd", "");
@@ -289,7 +294,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_grab_focus (button);
   gtk_widget_grab_default (button);
 
-  cb_disc_refreshed (priv->device_box, xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
+  cb_volume_changed (XFBURN_DEVICE_BOX (priv->device_box), TRUE, xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
   g_signal_connect (G_OBJECT (obj), "response", G_CALLBACK (cb_dialog_response), priv);
 
   return gobj;
@@ -304,6 +309,9 @@ xfburn_burn_data_composition_base_dialog_get_property (GObject * object, guint p
   case PROP_IMAGE:
     g_value_set_pointer (value, priv->image);
     break;
+  case PROP_SHOW_VOLUME_NAME:
+    g_value_set_boolean (value, priv->show_volume_name);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -319,6 +327,9 @@ xfburn_burn_data_composition_base_dialog_set_property (GObject * object, guint p
   case PROP_IMAGE:
     priv->image = g_value_get_pointer (value);
     break;
+  case PROP_SHOW_VOLUME_NAME:
+    priv->show_volume_name = g_value_get_boolean (value);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -331,7 +342,7 @@ xfburn_burn_data_composition_base_dialog_finalize (GObject * object)
   XfburnBurnDataCompositionBaseDialogPrivate *priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (object);
 
   iso_image_unref (priv->image);
-
+  
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -411,12 +422,12 @@ cb_browse_iso (GtkButton * button, XfburnBurnDataCompositionBaseDialog * dialog)
 }
 
 static void
-cb_disc_refreshed (GtkWidget *device_box, XfburnDevice *device, XfburnBurnDataCompositionBaseDialog * dialog)
+cb_volume_changed (XfburnDeviceBox *box, gboolean device_changed, XfburnDevice *device, XfburnBurnDataCompositionBaseDialog * dialog)
 {
   XfburnBurnDataCompositionBaseDialogPrivate *priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (dialog);
   gboolean valid_disc;
 
-  g_object_get (G_OBJECT (priv->device_box), "valid", &valid_disc, NULL);
+  g_object_get (box, "valid", &valid_disc, NULL);
 
   /*
    * Disabled: change button_proceed functionality
@@ -446,6 +457,7 @@ thread_write_iso (ThreadWriteIsoParams * params)
   glong size = 0;
   glong written = 0;
   guint i = 0;
+  int (*read_fn) (struct burn_source *src, unsigned char *buf, int size);
 
   fd = open (params->iso_path, O_WRONLY | O_CREAT | O_TRUNC, 0644);
   if (fd == -1) {
@@ -465,8 +477,13 @@ thread_write_iso (ThreadWriteIsoParams * params)
   xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Writing ISO..."));
 
   size = (glong) params->src->get_size (params->src);
+  if (params->src->read == NULL)
+    read_fn = params->src->read_xt;
+  else
+    read_fn = params->src->read;
+
   /* FIXME: is size really always 2048? */
-  while (params->src->read_xt (params->src, buf, 2048) == 2048) {
+  while (read_fn (params->src, buf, 2048) == 2048) {
     if (write (fd, buf, 2048) < 2048) {
       /* an error occured while writing */
       gchar err[256];
@@ -483,8 +500,8 @@ thread_write_iso (ThreadWriteIsoParams * params)
       i++;
 
       if (i >= 1000) {
-	i = 0;
 	gdouble percent = 0;
+	i = 0;
 
 	percent = ((gdouble) written / (gdouble) size);
 
@@ -521,16 +538,20 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   GtkWidget *dialog_progress = params->dialog_progress;
 
   struct burn_write_opts * burn_options;
+  struct burn_source **fifos = NULL;
   gint ret;
+  int sectors[1];
 
   ret = burn_disc_add_session (disc, session, BURN_POS_END);
   if (ret == 0) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to create disc object"));
+    g_warning ("Unable to create disc object");
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend."));
     return;
   }
 
   if (burn_track_set_source (track, params->src) != BURN_SOURCE_OK) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot attach source object to track object"));
+    g_warning ("Cannot attach source object to track object");
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend."));
     return;
   }
   
@@ -539,34 +560,33 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   burn_options = burn_write_opts_new (drive);
   burn_write_opts_set_perform_opc (burn_options, 0);
   burn_write_opts_set_multi (burn_options, 0);
-
-  switch (params->write_mode) {
-  case WRITE_MODE_TAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_TAO, BURN_BLOCK_MODE1);
-    break;
-  case WRITE_MODE_SAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_SAO, BURN_BLOCK_SAO);
-    break;
-  case WRITE_MODE_RAW16:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW16);
-    break;
-  case WRITE_MODE_RAW96P:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96P);
-    break;
-  case WRITE_MODE_RAW96R:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96R);
-    break;
-  default:
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently"));
-    return;
-  }
-
+  /* enable this when there is some time for testing
+  DBG ("Enabling multisession");
+  burn_write_opts_set_multi(burn_options, 1);
+  */
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
-  DBG ("Set speed to %d kb/s", params->speed);
-  burn_drive_set_speed (drive, 0, params->speed);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
 
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, disc, (params->is_fifo ? params->src : NULL));
+  if (!xfburn_set_write_mode (burn_options, params->write_mode, disc, WRITE_MODE_TAO)) {
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
+  } else {
+
+    DBG ("Set speed to %d kb/s", params->speed);
+    burn_drive_set_speed (drive, 0, params->speed);
+
+    sectors[0] = burn_disc_get_sectors (disc);
+
+    if (params->is_fifo) {
+      fifos = g_new(struct burn_source *,1);
+      fifos[0] = params->src;
+    }
+
+    xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, DATA_BYTES_PER_SECTOR, disc, fifos, sectors);
+
+    if (params->is_fifo) {
+      g_free (fifos);
+    }
+  }
 
   burn_write_opts_free (burn_options);
 }
@@ -582,30 +602,22 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
 
   struct burn_drive_info *drive_info = NULL;
 
-  if (!burn_initialize ()) {
-    g_critical ("Unable to initialize libburn");
-    burn_source_free (params->src);
-    g_free (params);
-    return;
-  }
-
   disc = burn_disc_create ();
   session = burn_session_create ();
   track = burn_track_create ();
 
   if (!xfburn_device_grab (params->device, &drive_info)) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab drive"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
   } else {
     thread_burn_prep_and_burn (params, drive_info->drive, disc, session, track);
-    burn_drive_release (drive_info->drive, params->eject ? 1 : 0);
+    xfburn_device_release (drive_info, params->eject);
   }
 
   burn_track_free (track);
   burn_session_free (session);
   burn_disc_free (disc);
-  burn_finish ();
-
   burn_source_free (params->src);
+
   g_free (params);
 }
 
@@ -629,16 +641,16 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
     iso_write_opts_new (&write_opts, 0);
 
     iso_write_opts_set_iso_level (write_opts, 2);
-    iso_write_opts_set_rockridge (write_opts, TRUE);
-    iso_write_opts_set_joliet (write_opts, TRUE);
-    iso_write_opts_set_allow_deep_paths (write_opts, TRUE);
+    iso_write_opts_set_rockridge (write_opts, 1);
+    iso_write_opts_set_joliet (write_opts, 1);
+    iso_write_opts_set_allow_deep_paths (write_opts, 1);
     /* not sure if we want that
     iso_write_opts_set_omit_version_numbers (write_opts, TRUE);
     */
 
     if (iso_image_create_burn_source (priv->image, write_opts, &src) < 0) {
       /* could not create source */
-      xfce_err (_("Could not create ISO source structure"));
+      xfce_err (_("Could not create ISO source structure."));
       return;
     }
 
@@ -672,8 +684,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
       speed = xfburn_device_box_get_speed (XFBURN_DEVICE_BOX (priv->device_box));
       write_mode = xfburn_device_box_get_mode (XFBURN_DEVICE_BOX (priv->device_box));
 
-      /* FIXME: how much buffer space do we need? Probably should put this into settings */
-      src_fifo = burn_fifo_source_new (src, 2048, xfburn_settings_get_int ("fifo-size", XFBURN_FIFO_DEFAULT_SIZE) / 2, 0);
+      src_fifo = burn_fifo_source_new (src, 2048, xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE) / 2, 0);
       burn_source_free (src);
 
       /* burn composition */
