@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-data-composition-base-dialog.h 5038 2008-07-09 16:29:27Z squisher $ */
 /*
  *  Copyright (c) 2005-2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -54,7 +53,7 @@ typedef struct
   XfceTitledDialogClass parent_class;
 } XfburnBurnDataCompositionBaseDialogClass;
 
-GtkType xfburn_burn_data_composition_base_dialog_get_type ();
+GType xfburn_burn_data_composition_base_dialog_get_type (void);
 
 GtkWidget *xfburn_burn_data_composition_base_dialog_new (IsoImage *image);
 
