@@ -1,4 +1,3 @@
-/* $Id: xfburn-copy-cd-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -47,9 +46,9 @@ typedef struct
   XfceTitledDialogClass parent_class;
 } XfburnCopyCdDialogClass;
 
-GType xfburn_copy_cd_dialog_get_type ();
+GType xfburn_copy_cd_dialog_get_type (void);
 
-GtkWidget *xfburn_copy_cd_dialog_new ();
+GtkWidget *xfburn_copy_cd_dialog_new (void);
 
 G_END_DECLS
 
