@@ -1,4 +1,3 @@
-/* $Id: xfburn-directory-browser.c 7700 2009-07-08 23:33:05Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -203,7 +202,7 @@ directory_tree_sortfunc (GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b,
 
 static void
 cb_browser_drag_data_get (GtkWidget * widget, GdkDragContext * dc,
-                          GtkSelectionData * data, guint info, guint time, gpointer user_data)
+                          GtkSelectionData * data, guint info, guint timestamp, gpointer user_data)
 {
   if (info == DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN) {
     gchar *full_paths = NULL;
