@@ -1,4 +1,3 @@
-/* $Id: xfburn-main-window.c 7677 2009-07-05 00:55:15Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -41,6 +40,7 @@
 #include "xfburn-settings.h"
 #include "xfburn-main.h"
 #include "xfburn-stock.h"
+#include "xfburn-utils.h"
 
 #define XFBURN_MAIN_WINDOW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_MAIN_WINDOW, XfburnMainWindowPrivate))
 
@@ -305,7 +305,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
 
   /* filebrowser */
   priv->file_browser = xfburn_file_browser_new ();
-  gtk_paned_add1 (GTK_PANED (priv->vpaned), priv->file_browser);
+  gtk_paned_pack1 (GTK_PANED (priv->vpaned), priv->file_browser, TRUE, FALSE);
   gtk_widget_show (priv->file_browser);
 
   gtk_paned_set_position (GTK_PANED (priv->file_browser), xfburn_settings_get_int ("hpaned-position", 250));
@@ -313,7 +313,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   /* compositions notebook */
   priv->compositions_notebook = xfburn_compositions_notebook_new ();
   gtk_widget_show (priv->compositions_notebook);
-  gtk_paned_add2 (GTK_PANED (priv->vpaned), priv->compositions_notebook);
+  gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->compositions_notebook, TRUE, FALSE);
   
   gtk_paned_set_position (GTK_PANED (priv->vpaned), xfburn_settings_get_int ("vpaned-position", 200));
 
@@ -681,7 +681,7 @@ xfburn_main_window_new (void)
 }
 
 XfburnMainWindow *
-xfburn_main_window_get_instance ()
+xfburn_main_window_get_instance (void)
 {
   if (!instance)
     g_warning ("No existing instance of XfburnMainWindow");
@@ -710,9 +710,12 @@ xfburn_main_window_add_data_composition_with_files (XfburnMainWindow *window, in
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
+  GSList * filelist;
  
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_DATA_COMPOSITION);
-  xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filec, filenames);
+
+  filelist = xfburn_make_abosulet_file_list (filec, filenames);
+  xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filelist);
 }
 
 void 
@@ -720,9 +723,11 @@ xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, i
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
+  GSList * filelist;
  
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_AUDIO_COMPOSITION);
-  xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filec, filenames);
+  filelist = xfburn_make_abosulet_file_list (filec, filenames);
+  xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filelist);
 }
 
 gboolean
