@@ -1,4 +1,3 @@
-/* $Id: xfburn-notebook-tab.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -64,7 +63,7 @@ static guint notebook_tab_signals[LAST_SIGNAL];
 /* class initiliazation */
 /************************/
 GType
-xfburn_notebook_tab_get_type ()
+xfburn_notebook_tab_get_type (void)
 {
   static GType type = 0;
 
