@@ -1,4 +1,3 @@
-/* $Id: xfburn-progress-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -112,7 +111,7 @@ xfburn_progress_dialog_status_get_type (void)
 static GtkDialogClass *parent_class = NULL;
 
 GType
-xfburn_progress_dialog_get_type ()
+xfburn_progress_dialog_get_type (void)
 {
   static GType type = 0;
 
