@@ -1,4 +1,3 @@
-/* $Id: xfburn-stock.h 5095 2008-07-15 15:05:01Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -22,13 +21,15 @@
 
 G_BEGIN_DECLS;
 
-#define XFBURN_STOCK_AUDIO_COPY     "xfburn-audio-copy"
-#define XFBURN_STOCK_BLANK_CDRW     "xfburn-blank-cdrw"
-#define XFBURN_STOCK_FORMAT_DVDRW   "xfburn-format-dvdrw"
-#define XFBURN_STOCK_BURN_CD        "xfburn-burn-cd"
-#define XFBURN_STOCK_CD             "xfburn-cd"
-#define XFBURN_STOCK_DATA_COPY      "xfburn-data-copy"
-#define XFBURN_STOCK_IMPORT_SESSION "xfburn-import-session"
+#define XFBURN_STOCK_AUDIO_COPY           "xfburn-audio-copy"
+#define XFBURN_STOCK_BLANK_CDRW           "xfburn-blank-cdrw"
+#define XFBURN_STOCK_FORMAT_DVDRW         "xfburn-format-dvdrw"
+#define XFBURN_STOCK_AUDIO_CD             "xfburn-audio-cd"
+#define XFBURN_STOCK_BURN_CD              "xfburn-burn-cd"
+#define XFBURN_STOCK_CD                   "xfburn-cd"
+#define XFBURN_STOCK_DATA_COPY            "xfburn-data-copy"
+#define XFBURN_STOCK_IMPORT_SESSION       "xfburn-import-session"
+#define XFBURN_STOCK_NEW_DATA_COMPOSITION "xfburn-new-data-composition"
 
 void xfburn_stock_init (void);
 
