@@ -1,4 +1,3 @@
-/* $Id: xfburn-transcoder-gst.c 7563 2009-06-14 05:44:05Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (dmohr@mcbf.net)
@@ -156,7 +155,7 @@ static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
 GType
-xfburn_transcoder_gst_get_type ()
+xfburn_transcoder_gst_get_type (void)
 {
   static GType type = 0;
 
@@ -683,7 +682,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
 
     gchar *error_msg = "File content has a decoder but is not audio.";
 
-    DBG (error_msg);
+    DBG ("%s", error_msg);
     
     gst_caps_unref (caps);
     gst_object_unref (audiopad);
@@ -1026,7 +1025,7 @@ is_initialized (XfburnTranscoder *trans, GError **error)
 /*        */
 
 GObject *
-xfburn_transcoder_gst_new ()
+xfburn_transcoder_gst_new (void)
 {
   return g_object_new (XFBURN_TYPE_TRANSCODER_GST, NULL);
 }
