@@ -1,4 +1,3 @@
-/* $Id: xfburn-utils.c 7677 2009-07-05 00:55:15Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -65,16 +64,16 @@ xfburn_default_cursor (GtkWidget * widget)
 gchar *
 xfburn_humanreadable_filesize (guint64 size)
 {
-  if (!xfburn_settings_get_boolean ("human-readable-units", TRUE))
-    return g_strdup_printf ("%lu B", (long unsigned int) size);
-  
-  /* copied from GnomeBaker */
-
   gchar *ret = NULL;
   const gchar *unit_list[5] = { "B ", "KB", "MB", "GB", "TB" };
   gint unit = 0;
   gdouble human_size = (gdouble) size;
 
+  if (!xfburn_settings_get_boolean ("human-readable-units", TRUE))
+    return g_strdup_printf ("%lu B", (long unsigned int) size);
+  
+  /* copied from GnomeBaker */
+
   while (human_size > 1024 && unit < 4) {
     human_size = human_size / 1024;
     unit++;
@@ -182,7 +181,7 @@ xfburn_ask_yes_no (GtkMessageType type, const gchar *primary_text, const gchar *
 static char * libburn_msg_prefix = "libburn-";
 
 void
-xfburn_capture_libburn_messages ()
+xfburn_capture_libburn_messages (void)
 {
   int ret;
 
@@ -197,7 +196,7 @@ xfburn_capture_libburn_messages ()
 }
 
 void
-xfburn_console_libburn_messages ()
+xfburn_console_libburn_messages (void)
 {
   int ret;
 
@@ -212,3 +211,28 @@ xfburn_console_libburn_messages ()
  
 }
 
+
+GSList *
+xfburn_make_abosulet_file_list (gint count, gchar *filenames[])
+{
+  gint i;
+  GSList * list = NULL;
+  gchar *file, *abs, *pwd;
+
+  pwd = g_get_current_dir ();
+
+  for (i=0; i<count; i++) {
+    file = filenames[i];
+
+    if (!g_path_is_absolute (file))
+      abs = g_build_filename (pwd, file, NULL);
+    else
+      abs = g_build_filename (file, NULL);
+
+    list = g_slist_prepend (list, abs);
+  }
+
+  g_free (pwd);
+
+  return list;
+}
