@@ -1,4 +1,3 @@
-/* $Id: xfburn-utils.h 5039 2008-07-09 18:45:08Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -33,8 +32,13 @@ void xfburn_default_cursor (GtkWidget *);
 
 gchar *xfburn_humanreadable_filesize (guint64);
 guint64 xfburn_calc_dirsize (const gchar *);
+GSList * xfburn_make_abosulet_file_list (gint count, gchar *filenames[]);
 
 void xfburn_browse_for_file (GtkEntry *entry, GtkWindow *parent);
 
 gboolean xfburn_ask_yes_no (GtkMessageType type, const gchar *primary_text, const gchar *secondary_text);
+
+void xfburn_capture_libburn_messages (void);
+void xfburn_console_libburn_messages (void);
+
 #endif
